==> haskell-parsers-0.12.9-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.9
id: parsers-0.12.9-7HsdFZVhf7h8ve9hE5PUwy
key: parsers-0.12.9-7HsdFZVhf7h8ve9hE5PUwy
license: BSD-3-Clause
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
abi: 49e471c7b92da3f77d99bd8bf60c85ee
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
import-dirs: /usr/lib/ghc-8.4.3/site-local/parsers-0.12.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/parsers-0.12.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/parsers-0.12.9
hs-libraries: HSparsers-0.12.9-7HsdFZVhf7h8ve9hE5PUwy
depends:
    base-4.11.1.0 base-orphans-0.8-3Ndp0ohh7rtBqRP3qW2F5j
    charset-0.3.7.1-JijN2t5Eesc2AwGGSO8bOM containers-0.5.11.0
    parsec-3.1.13.0 attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    text-1.2.3.0 transformers-0.5.5.0 mtl-2.2.2
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y binary-0.8.5.1
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-3Ndp0ohh7rtBqRP3qW2F5j=a0188b579af839f9c8290c33a86ab883
             charset-0.3.7.1-JijN2t5Eesc2AwGGSO8bOM=fb886e1c4c742001e3f0a7a1fd5bc3d5
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.9-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.9
id: parsers-0.12.9-9KHXU2ILDNi1WRhatxpbQz
key: parsers-0.12.9-9KHXU2ILDNi1WRhatxpbQz
license: BSD-3-Clause
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
abi: a9f40d74f8f0180d38270d472e9f7e3e
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
import-dirs: /usr/lib/ghc-8.4.3/site-local/parsers-0.12.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/parsers-0.12.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/parsers-0.12.9
hs-libraries: HSparsers-0.12.9-9KHXU2ILDNi1WRhatxpbQz
depends:
    base-4.11.1.0 base-orphans-0.8-DMkdJwLFak2DoFZzwzdOJW
    charset-0.3.7.1-JijN2t5Eesc2AwGGSO8bOM containers-0.5.11.0
    parsec-3.1.13.0 attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    text-1.2.3.0 transformers-0.5.5.0 mtl-2.2.2
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y binary-0.8.5.1
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-DMkdJwLFak2DoFZzwzdOJW=8fdd269bb784bcdf160da8c61c0e0531
             charset-0.3.7.1-JijN2t5Eesc2AwGGSO8bOM=fb886e1c4c742001e3f0a7a1fd5bc3d5
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
